try_init

Function try_init 

pub fn try_init(config: PropertyConfig) -> Result<()>
Initialize system properties, returning an error when an option cannot be applied (typically because it was already set on a previous call).